function []=CreateMoselCode()
% A function that performs necessary calculations and writes both primal an
% dual problem to text-files with mosel-code
T=60;

%    DATA       

G= 7;                   %number of generator types
intL=10;                %number of internal lines(skal alltid komme frst i rekkeflge
exL=4;                  %number of export lines
impL=4;                 %number of import lines
L=intL+exL+impL;
A= 4;                   %number of areas ("NO" "SE" "FI" "DK")
n=G*A+L;
Losses= 0.01;
OutsideRegions= [5 6 7];%"GE" "NL" "PO" (index j)
NyNum=6;                %number of uncertain parameters in each time period
k(1)=1;
for i=1:T-1
    m(i)=A+2*(A-1)+2*A*G+2*L;
    k(i+1)=k(i)+NyNum;
end
m(T)=A+4*(A-1)+2*A*G+2*L;
FrA=[1	1	1	2	2	2	4	4	3	3	1	2	2	4	5	5	6	7]; 
ToA=[2	4	3	1	4	3	1	2	1	2	6	5	7	5	2	4	1	2]; 


%    GET MATRICES       

[PMat AMat BMat CMat MMat M  h WMat XMat OMat GamMat YMat FiMat PsiMat]= matrices(T,G,A,intL,exL,impL,L,FrA,ToA,Losses,m,k,n,NyNum);


% CREATE PRIMAL PROBLEM     

filename=['PrimalProblem_T' , num2str(T), '.txt'];
fileID = fopen(filename,'w');
%lager objektivfunksjonen
Objectivefunction= sym('Obj',[1 1]);
Objectivefunction(1,1)=0;

for t=1:T
    Objectivefunction=Objectivefunction+trace(PMat{t}*M*(PMat{t}.')*(CMat{t}.')*XMat{t});   
end

Objective = strcat(char(Objectivefunction), ';');
fprintf(fileID,'%s\n','!Objective');
fprintf(fileID,'%s\n\n',Objective);


%Constraint 1
first= sym('first',[1 1]);
first(1,1)=0;

total= sym('total',[1 1]);
total(1,1)=0;

Constr1Mat=cell(T,1);
Constr2Mat=cell(T,1);
Constr3Mat=cell(T,1);
Constr4Mat=cell(T,1);


fprintf(fileID,'%s\n','!Constraints');
for t=1:T %inni denne T-lkka kommer alle de fire forskjellige constraint-matrisene
   fprintf(fileID,'%s','!Timeperiod: ');
   fprintf(fileID,'%d\n\n',t );    
    
   %Creating the matrices 
   %constraint 1
    Constr1Mat{t}=sym('c',[m(t) k(T)]);
    Constr1Mat{t}(1:m(t),1:k(T))=0;
     
    for s=1:T 
     Constr1Mat{t}=Constr1Mat{t}+AMat{t,s}*XMat{s}*PMat{s}*MMat{t}*PMat{t};

    end  
   Constr1Mat{t}= Constr1Mat{t} - BMat{t}*PMat{t}-OMat{t}*WMat;

    %constraint 2
    Constr2Mat{t}=sym('c',[m(t) 1]);
    Constr2Mat{t}=OMat{t}*h;
    
    %constraint 3
    Constr3Mat{t}=sym('c',[n k(T)]);
    Constr3Mat{t}=XMat{t}*PMat{t}-GamMat{t}*WMat;
   
    %constraint 4
    Constr4Mat{t}=sym('c',[n 1]);
    Constr4Mat{t}=GamMat{t}*h;
   
   
   %Writing to file 
   %constraint1
   fprintf(fileID,'%s\n\n','!Constraints 1');
   for i =1:m(t)
       for j =1:k(T)
           fprintf(fileID,'%s\n',[char(Constr1Mat{t}(i,j)) '=0;']);
       end
   end
  
   %constraint 2
    fprintf(fileID,'%s\n\n','!Constraints 2');
   for i =1:m(t)    
          fprintf(fileID,'%s\n',[char(Constr2Mat{t}(i)) '>=0;']); 
   end
   
   %constraint 3
   fprintf(fileID,'%s\n\n','!Constraints 3');
   for i =1:n  
       for j=1:k(T)
          fprintf(fileID,'%s\n',[char(Constr3Mat{t}(i,j)) '=0;']);
       end
   end
 
   %constraint 4
   fprintf(fileID,'%s\n\n','!Constraints 4');
   for i =1:n    
          fprintf(fileID,'%s\n',[char(Constr4Mat{t}(i)) '>=0;']); 
   end
  
end
fclose(fileID);

% CREATE DUAL PROBLEM     

filename=['DualProblem_T' , num2str(T), '.txt'];
fileID = fopen(filename,'w');

%lager objektivfunksjonen
Objectivefunction= sym('Obj',[1 1]);
Objectivefunction(1,1)=0;

for t=1:T
    Objectivefunction=Objectivefunction+trace(PMat{t}*M*(PMat{t}.')*(BMat{t}.')*YMat{t});   
end

Objective = strcat(char(Objectivefunction), ';');

fprintf(fileID,'%s\n','!Objective');
fprintf(fileID,'%s\n\n',Objective);

Constr1Mat=cell(T,1);
Constr2Mat=cell(T,1);
Constr3Mat=cell(T,1);
Constr4Mat=cell(T,1);

fprintf(fileID,'%s\n','!Constraints');
for t=1:T 
   fprintf(fileID,'%s','!Timeperiod: ');
   fprintf(fileID,'%d\n\n',t );    
    
   %Creating the constraints 
   %constraint 1
   Constr1Mat{t}=sym('c',[n k(T)]);
   Constr1Mat{t}(1:n,1:k(T))=0;
     
   for s=1:T 
       Constr1Mat{t}=Constr1Mat{t}+(AMat{s,t}.')*YMat{s}*PMat{s}*MMat{t}*PMat{t};
   end  
   Constr1Mat{t}= Constr1Mat{t} - CMat{t}*PMat{t}- FiMat{t}*WMat;
  
   %constraint 2
   Constr2Mat{t}=sym('c',[n 1]);
   Constr2Mat{t}=FiMat{t}*h;
   
   %constraint 3
   Constr3Mat{t}=sym('c',[m(t) k(T)]);
   Constr3Mat{t}=YMat{t}*PMat{t}-PsiMat{t}*WMat;
  
   %constraint 4
   Constr4Mat{t}=sym('c',[m(t) 1]);
   Constr4Mat{t}=PsiMat{t}*h;
   
   %Write to file 
   %constraint 3
   fprintf(fileID,'%s\n\n','!Constraints 1');
   for i =1:n 
       for j=1:k(T)
          fprintf(fileID,'%s\n',[char(Constr1Mat{t}(i,j)) '=0;']);
       end
   end 
   
   %constraint 2
   fprintf(fileID,'%s\n\n','!Constraints 2');
   for i =1:n    
       fprintf(fileID,'%s\n',[char(Constr2Mat{t}(i)) '<=0;']); 
   end
   
   %constraint 3
   fprintf(fileID,'%s\n\n','!Constraints 3');
   for i =1:m(t) 
       for j=1:k(T)
          fprintf(fileID,'%s\n',[char(Constr3Mat{t}(i,j)) '=0;']);
       end
   end  
  
   %constraint 4
   fprintf(fileID,'%s\n\n','!Constraints 4');
   for i =1:m(t)  
          fprintf(fileID,'%s\n',[char(Constr4Mat{t}(i)) '>=0;']); 
   end
   
end
fclose(fileID);
end
